@@ -1,7 +1,7 @@
 #############################################################################
 #
 # XLConnect
-# Copyright (C) 2010-2021 Mirai Solutions GmbH
+# Copyright (C) 2010-2024 Mirai Solutions GmbH
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -58,19 +58,19 @@
   sharedPaths <- tryCatch({
     c(
       xlcEnsureDependenciesFor(
-      paste0(apachePrefix, "/poi/poi-ooxml-full/5.2.3/poi-ooxml-full-5.2.3.jar"), "poi-ooxml-full.jar", 
-      "5.2.3",  libname, pkgname),
+      paste0(apachePrefix, "/poi/poi-ooxml-full/5.2.5/poi-ooxml-full-5.2.5.jar"), "poi-ooxml-full.jar", 
+      "5.2.5",  libname, pkgname),
     xlcEnsureDependenciesFor(
-      paste0(apachePrefix, "/poi/poi-ooxml/5.2.3/poi-ooxml-5.2.3.jar"), "poi-ooxml.jar", 
-      "5.2.3",  libname, pkgname, debianpkg = "libapache-poi-java", rpmpkg="apache-poi"),
+      paste0(apachePrefix, "/poi/poi-ooxml/5.2.5/poi-ooxml-5.2.5.jar"), "poi-ooxml.jar", 
+      "5.2.5",  libname, pkgname, debianpkg = "libapache-poi-java", rpmpkg="apache-poi"),
     xlcEnsureDependenciesFor(
-      paste0(apachePrefix, "/poi/poi/5.2.3/poi-5.2.3.jar"), "poi.jar", 
-      "5.2.3",  libname, pkgname, debianpkg = "libapache-poi-java", rpmpkg="apache-poi"),
+      paste0(apachePrefix, "/poi/poi/5.2.5/poi-5.2.5.jar"), "poi.jar", 
+      "5.2.5",  libname, pkgname, debianpkg = "libapache-poi-java", rpmpkg="apache-poi"),
     xlcEnsureDependenciesFor(
-      paste0(apachePrefix, "/commons/commons-compress/1.21/commons-compress-1.21.jar"), "commons-compress.jar",
-      "1\\.(1[8-9]|[2-9][0-9]).*",  libname, pkgname, debianpkg = "libcommons-compress-java", rpmpkg="apache-commons-compress"),
+      paste0(apachePrefix, "/commons/commons-compress/1.25.0/commons-compress-1.25.0.jar"), "commons-compress.jar",
+      "1\\.(2[5-9]|[2-9][0-9]).*",  libname, pkgname, debianpkg = "libcommons-compress-java", rpmpkg="apache-commons-compress"),
     xlcEnsureDependenciesFor(
-      paste0(apachePrefix, "/xmlbeans/xmlbeans/5.1.1/xmlbeans-5.1.1.jar"), "xmlbeans.jar",
+      paste0(apachePrefix, "/xmlbeans/xmlbeans/5.2.0/xmlbeans-5.2.0.jar"), "xmlbeans.jar",
       "5\\..*",  libname, pkgname, debianpkg="libxmlbeans-java"),
     xlcEnsureDependenciesFor(
       paste0(apachePrefix, "/commons/commons-collections4/4.4/commons-collections4-4.4.jar"), "commons-collections4.jar",
@@ -79,16 +79,16 @@
       paste0(apachePrefix, "/commons/commons-math3/3.6.1/commons-math3-3.6.1.jar"), "commons-math3.jar",
       "3\\.([6-9]|1[0-9]).*",  libname, pkgname, debianpkg="libcommons-math3-java"),
     xlcEnsureDependenciesFor(
-      paste0(apachePrefix, "/logging/log4j/log4j-api/2.18.0/log4j-api-2.18.0.jar"), "log4j-api.jar",
-      "2.17.2",  libname, pkgname),
+      paste0(apachePrefix, "/logging/log4j/log4j-api/2.21.1/log4j-api-2.21.1.jar"), "log4j-api.jar",
+      "2.21.1",  libname, pkgname),
     xlcEnsureDependenciesFor(
-      paste0(repo, "/commons-codec/commons-codec/1.15/commons-codec-1.15.jar"), "commons-codec-1.15.jar",
+      paste0(repo, "/commons-codec/commons-codec/1.16.0/commons-codec-1.16.0.jar"), "commons-codec-1.16.0.jar",
       "1\\.(1[1-9]|[2-9][0-9]).*",  libname, pkgname, debianpkg="libcommons-codec-java", rpmpkg="apache-commons-codec"),
     xlcEnsureDependenciesFor(
-      paste0(repo, "/commons-io/commons-io/2.11.0/commons-io-2.11.0.jar"), "commons-io-2.11.0.jar",
-      "2\\.(1[1-9]|[2-9][0-9]).*",  libname, pkgname, debianpkg="libcommons-io-java", rpmpkg="apache-commons-io"),
+      paste0(repo, "/commons-io/commons-io/2.15.0/commons-io-2.15.0.jar"), "commons-io-2.15.0.jar",
+      "2\\.(1[5-9]|[2-9][0-9]).*",  libname, pkgname, debianpkg="libcommons-io-java", rpmpkg="apache-commons-io"),
     xlcEnsureDependenciesFor(
-      paste0(repo, "/com/zaxxer/SparseBitSet/1.2/SparseBitSet-1.2.jar"), "SparseBitSet.jar",
+      paste0(repo, "/com/zaxxer/SparseBitSet/1.3/SparseBitSet-1.3.jar"), "SparseBitSet.jar",
       "1\\.([2-9]|[1-9][0-9]).*",  libname, pkgname)
     )
   },
