@@ -1,7 +1,7 @@
 #############################################################################
 #
 # XLConnect
-# Copyright (C) 2010-2021 Mirai Solutions GmbH
+# Copyright (C) 2010-2024 Mirai Solutions GmbH
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,47 +23,47 @@
 # Tests whether data.frame's pushed and pulled to/from Java
 # are consistent (with respect to some defined differences;
 # see 'normalizeDataframe')
-# 
+#
 # Author: Martin Studer, Mirai Solutions GmbH
 #
 #############################################################################
 
 test.dataframeConversion <- function() {
-	
+
 	testDataFrame <- function(df) {
 		res <- XLConnect:::dataframeFromJava(XLConnect:::dataframeToJava(df), check.names = TRUE)
 		checkEquals(normalizeDataframe(df), res, check.attributes = FALSE, check.names = TRUE)
 	}
-	
+
 	if(getOption("FULL.TEST.SUITE")) {
 		# built-in dataset mtcars
 		testDataFrame(mtcars)
-		
+
 		# built-in dataset airquality
 		testDataFrame(airquality)
-		
+
 		# built-in dataset attenu
 		testDataFrame(attenu)
-		
+
 		# built-in dataset ChickWeight
 		testDataFrame(ChickWeight)
-		
+
 		# built-in dataset CO2
 		testDataFrame(CO2)
-		
+
 		# built-in dataset iris
 		testDataFrame(iris)
-		
+
 		# built-in dataset longley
 		testDataFrame(longley)
-		
+
 		# built-in dataset morley
 		testDataFrame(morley)
-		
+
 		# built-in dataset swiss
 		testDataFrame(swiss)
 	}
-	
+
 	# custom test dataset
 	cdf <- data.frame(
 			"Column.A" = c(1, 2, 3, NA, 5, Inf, 7, 8, NA, 10),
@@ -73,21 +73,22 @@ test.dataframeConversion <- function() {
 			"Column.E" = c(TRUE, TRUE, NA, NA, FALSE, FALSE, TRUE, NA, FALSE, TRUE),
 			"Column.F" = c("High", "Medium", "Low", "Low", "Low", NA, NA, "Medium", "High", "High"),
 			"Column.G" = c("High", "Medium", NA, "Low", "Low", "Medium", NA, "Medium", "High", "High"),
-			"Column.H" = rep(c(Sys.Date(), Sys.Date() + 236, NA), length = 10),
+			"Column.H" = rep(c(as.Date("2021-10-30") , as.Date("2021-03-28"), NA), length = 10),
 			# NOTE: Column.I is automatically converted to POSIXct!!!
-			"Column.I" = rep(c(as.POSIXlt(Sys.time()), as.POSIXlt(Sys.time()) + 3523523, NA, as.POSIXlt(Sys.time()) + 838239), length = 10),
-			"Column.J" = rep(c(as.POSIXct(Sys.time()), as.POSIXct(Sys.time()) + 436322, NA, as.POSIXct(Sys.time()) - 1295022), length = 10),
+			"Column.I" = rep(c(as.POSIXlt("2021-10-31 03:00:00"), as.POSIXlt(1582963631, origin="1970-01-01"), NA, as.POSIXlt("2001-12-31 23:59:59")), length = 10),
+			# NOTE: 1582963631 with origin="1970-01-01" corresponds to 2020 Feb 29
+			"Column.J" = rep(c(as.POSIXct("2021-10-31 03:00:00"), as.POSIXct(1582963631, origin="1970-01-01"), NA, as.POSIXct("2001-12-31 23:59:59")), length = 10),
 			stringsAsFactors = F
 	)
 	cdf[["Column.F"]] <- factor(cdf[["Column.F"]])
 	cdf[["Column.F"]] <- ordered(cdf[["Column.F"]], levels = c("Low", "Medium", "High"))
-	
+
 	testDataFrame(cdf)
-	
+
 	# Check that when being supplied with an object that is not coercable
 	# into a data.frame, an appropriate exception is thrown
 	checkException(XLConnect:::dataframeToJava(search))
-	
+
 	# Check that exceptions are thrown when calling dataframeFromJava
 	# with inappropriate objects
 	checkException(XLConnect:::dataframeFromJava(NULL))
