@@ -1,7 +1,7 @@
 #############################################################################
 #
 # XLConnect
-# Copyright (C) 2010-2021 Mirai Solutions GmbH
+# Copyright (C) 2010-2024 Mirai Solutions GmbH
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,17 +22,17 @@
 #
 # Tests for checking equality of data.frame's being written to and read
 # from Excel named regions
-# 
+#
 # Author: Martin Studer, Mirai Solutions GmbH
 #
 #############################################################################
 
 test.writeAndReadNamedRegion <- function() {
-	
+
 	# Create workbooks
 	wb.xls <- loadWorkbook(rsrc("resources/testWriteAndReadNamedRegion.xls"), create = TRUE)
 	wb.xlsx <- loadWorkbook(rsrc("resources/testWriteAndReadNamedRegion.xlsx"), create = TRUE)
-	
+
 	testDataFrame <- function(wb, df, lref) {
 		namedRegion <- deparse(substitute(df))
 		createSheet(wb, name = namedRegion)
@@ -41,55 +41,55 @@ test.writeAndReadNamedRegion <- function() {
 		res <- readNamedRegion(wb, namedRegion)
 		checkEquals(normalizeDataframe(df, replaceInf = TRUE), res, check.attributes = FALSE, check.names = TRUE)
 	}
-	
+
 	if(getOption("FULL.TEST.SUITE")) {
 		# built-in dataset mtcars (*.xls)
 		testDataFrame(wb.xls, mtcars, "$C$8")
 		# built-in dataset mtcars (*.xlsx)
 		testDataFrame(wb.xlsx, mtcars, "$C$8")
-		
+
 		# built-in dataset airquality (*.xls)
 		testDataFrame(wb.xls, airquality, "$F$13")
 		# built-in dataset airquality (*.xlsx)
 		testDataFrame(wb.xlsx, airquality, "$F$13")
-		
+
 		# built-in dataset attenu (*.xls)
 		testDataFrame(wb.xls, attenu, "$A$8")
 		# built-in dataset attenu (*.xlsx)
 		testDataFrame(wb.xlsx, attenu, "$A$8")
-		
+
 		# built-in dataset ChickWeight (*.xls)
 		testDataFrame(wb.xls, ChickWeight, "$BQ$7")
 		# built-in dataset ChickWeight (*.xlsx)
 		testDataFrame(wb.xlsx, ChickWeight, "$BQ$7")
-		
+
 		# built-in dataset CO2 (*.xls)
 		CO = CO2 # CO2 seems to be an illegal name
 		testDataFrame(wb.xls, CO, "$L$1")
 		# built-in dataset CO2 (*.xlsx)
 		testDataFrame(wb.xlsx, CO, "$L$1")
-		
+
 		# built-in dataset iris (*.xls)
 		testDataFrame(wb.xls, iris, "$BB$5")
 		# built-in dataset iris (*.xlsx)
 		testDataFrame(wb.xlsx, iris, "$BB$5")
-		
+
 		# built-in dataset longley (*.xls)
 		testDataFrame(wb.xls, longley, "$AD$8")
 		# built-in dataset longley (*.xlsx)
 		testDataFrame(wb.xlsx, longley, "$AD$8")
-		
+
 		# built-in dataset morley (*.xls)
 		testDataFrame(wb.xls, morley, "$K$4")
 		# built-in dataset morley (*.xlsx)
 		testDataFrame(wb.xlsx, morley, "$K$4")
-		
+
 		# built-in dataset swiss (*.xls)
 		testDataFrame(wb.xls, swiss, "$M$2")
 		# built-in dataset swiss (*.xlsx)
 		testDataFrame(wb.xlsx, swiss, "$M$2")
 	}
-	
+
 	# custom test dataset
 	cdf <- data.frame(
 			"Column.A" = c(1, 2, 3, NA, 5, Inf, 7, 8, NA, 10),
@@ -99,34 +99,35 @@ test.writeAndReadNamedRegion <- function() {
 			"Column.E" = c(TRUE, TRUE, NA, NA, FALSE, FALSE, TRUE, NA, FALSE, TRUE),
 			"Column.F" = c("High", "Medium", "Low", "Low", "Low", NA, NA, "Medium", "High", "High"),
 			"Column.G" = c("High", "Medium", NA, "Low", "Low", "Medium", NA, "Medium", "High", "High"),
-			"Column.H" = rep(c(Sys.Date(), Sys.Date() + 236, NA), length = 10),
+			"Column.H" = rep(c(as.Date("2021-10-30") , as.Date("2021-03-28"), NA), length = 10),
 			# NOTE: Column.I is automatically converted to POSIXct!!!
-			"Column.I" = rep(c(as.POSIXlt(Sys.time()), as.POSIXlt(Sys.time()) + 3523523, NA, as.POSIXlt(Sys.time()) + 838239), length = 10),
-			"Column.J" = rep(c(as.POSIXct(Sys.time()), as.POSIXct(Sys.time()) + 436322, NA, as.POSIXct(Sys.time()) - 1295022), length = 10),
+			"Column.I" = rep(c(as.POSIXlt("2021-10-31 03:00:00"), as.POSIXlt(1582963631, origin="1970-01-01"), NA, as.POSIXlt("2001-12-31 23:59:59")), length = 10),
+			# NOTE: 1582963631 with origin="1970-01-01" corresponds to 2020 Feb 29
+			"Column.J" = rep(c(as.POSIXct("2021-10-31 03:00:00"), as.POSIXct(1582963631, origin="1970-01-01"), NA, as.POSIXct("2001-12-31 23:59:59")), length = 10),
 			stringsAsFactors = F
 	)
 	cdf[["Column.F"]] <- factor(cdf[["Column.F"]])
 	cdf[["Column.F"]] <- ordered(cdf[["Column.F"]], levels = c("Low", "Medium", "High"))
-	
+
 	# (*.xls)
 	testDataFrame(wb.xls, cdf, "$X$100")
 	# (*.xlsx)
 	testDataFrame(wb.xlsx, cdf, "$X$100")
-	
+
 	# Check writing of data.frame with row names (*.xls)
 	createSheet(wb.xls, name = "rownames")
 	createName(wb.xls, name = "rownames", formula = "rownames!$F$16")
 	writeNamedRegion(wb.xls, mtcars, name = "rownames", header = TRUE, rownames = "Car")
 	res <- readNamedRegion(wb.xls, "rownames")
 	checkEquals(XLConnect:::includeRownames(mtcars, "Car"), res, check.attributes = FALSE, check.names = TRUE)
-	
+
 	# Check writing of data.frame with row names (*.xlsx)
 	createSheet(wb.xlsx, name = "rownames")
 	createName(wb.xlsx, name = "rownames", formula = "rownames!$F$16")
 	writeNamedRegion(wb.xlsx, mtcars, name = "rownames", header = TRUE, rownames = "Car")
 	res <- readNamedRegion(wb.xlsx, "rownames")
 	checkEquals(XLConnect:::includeRownames(mtcars, "Car"), res, check.attributes = FALSE, check.names = TRUE)
-	
+
 	# Check writing & reading of data.frame with row names (*.xls)
 	createSheet(wb.xls, name = "rownames2")
 	createName(wb.xls, name = "rownames2", formula = "rownames2!$K$5")
@@ -134,7 +135,7 @@ test.writeAndReadNamedRegion <- function() {
 	res <- readNamedRegion(wb.xls, "rownames2", rownames = "Car")
 	checkEquals(mtcars, res, check.attributes = FALSE, check.names = TRUE)
 	checkEquals(attr(mtcars, "row.names"), attr(res, "row.names"))
-	
+
 	# Check writing & reading of data.frame with row names (*.xlsx)
 	createSheet(wb.xlsx, name = "rownames2")
 	createName(wb.xlsx, name = "rownames2", formula = "rownames2!$K$5")
